@@ -24,10 +24,11 @@ def main(argv=None, abort=None, debug=None):
     argv = sys.argv[1:] if argv is None else argv
     debug = debug if debug else DEBUG
     abort = abort if abort else ABORT
-    for arg in argv:
-        if not pathlib.Path(arg).is_file() and not pathlib.Path(arg).is_dir():
+    unique_trees = {arg: None for arg in argv}
+    for tree_or_leaf in unique_trees:
+        if not pathlib.Path(tree_or_leaf).is_file() and not pathlib.Path(tree_or_leaf).is_dir():
             print("ERROR: For now only existing paths accepted.")
             sys.exit(2)
 
-    code, _ = lint.main(argv, abort=abort, debug=debug)
+    code, _ = lint.main(unique_trees, abort=abort, debug=debug)
     return code
